/**
 * 邮箱
 * @param {*} s
 */
export function isEmail(s) {
	return /^([a-zA-Z0-9_-])+@([a-zA-Z0-9_-])+((.[a-zA-Z0-9_-]{2,3}){1,2})$/.test(s)
}

/**
 * 手机号码
 * @param {*} s
 */
export function isMobile(s) {
	return /^1((34[0-8])|(8\d{2})|(([35][0-35-9]|4[579]|66|7[35678]|9[1389])\d{1}))\d{7}$/.test(s)
}

/**
 * 用户名
 * @param {*} s
 */
export function isUserName(s) {
	return /^[a-zA-Z0-9\u4e00-\u9fa5]{2,30}/.test(s)
}

/**
 * 密码
 * @param {*} s 只能输入6-16位,必须包括数字、字母、特殊字符其中两种
 */
export function isPwd(s) {
	return /^(?![0-9]+$)(?![a-z]+$)(?![A-Z]+$)(?!([^(0-9a-zA-Z)]|[\\(\\)])+$)([^(0-9a-zA-Z)]|[\\(\\)]|[a-z]|[A-Z]|[0-9])[^\\u4e00-\\u9fa5]{6,16}$/
		.test(s)
}

/**
 * URL地址
 * @param {*} s
 */
export function isURL(s) {
	return /^http[s]?:\/\/.*/.test(s)
}

/**
 * 电话号码
 * @param {*} s
 */
export function isPhone(phone) {
	if (!(/^1[3-9]\d{9}$/).test(phone)) {
		return {
			data: '手机号只能由11位数字组成',
			state: false
		}
	} else {
		return {
			data: '',
			state: true
		}
	}
}
//中文字符校验
export function isChineseWord(str) {
	if (!str) {
		return {
			data: '您输入的姓名不可以为空',
			state: false
		}
	}
	//  else if (!(/^[\u4e00-\u9fa5]*$/).test(str)) {
	//     return {
	//         data: '姓名只能由中文组成',
	//         state: false
	//     }
	// }
	else {
		return {
			data: '',
			state: true
		}
	}
}

/**
 * 身份证号
 * @param {*} s
 */
export function isID(sId) {
	if (!/(^\d{15}$)|(^\d{17}(\d|X|x)$)/.test(sId)) {
		return {
			data: '你输入的身份证长度或格式有误',
			state: false
		}
	}
	//身份证城市
	var aCity = {
		11: "北京",
		12: "天津",
		13: "河北",
		14: "山西",
		15: "内蒙古",
		21: "辽宁",
		22: "吉林",
		23: "黑龙江",
		31: "上海",
		32: "江苏",
		33: "浙江",
		34: "安徽",
		35: "福建",
		36: "江西",
		37: "山东",
		41: "河南",
		42: "湖北",
		43: "湖南",
		44: "广东",
		45: "广西",
		46: "海南",
		50: "重庆",
		51: "四川",
		52: "贵州",
		53: "云南",
		54: "西藏",
		61: "陕西",
		62: "甘肃",
		63: "青海",
		64: "宁夏",
		65: "新疆",
		71: "台湾",
		81: "香港",
		82: "澳门",
		91: "国外"
	};
	if (!aCity[parseInt(sId.substr(0, 2))]) {
		return {
			data: '你的身份证地区有误',
			state: false
		}
	}

	// 出生日期验证
	var sBirthday = (sId.substr(6, 4) + "-" + Number(sId.substr(10, 2)) + "-" + Number(sId.substr(12, 2))).replace(/-/g,
			"/"),
		d = new Date(sBirthday)
	if (sBirthday != (d.getFullYear() + "/" + (d.getMonth() + 1) + "/" + d.getDate())) {
		return {
			data: '身份证上的出生日期有误',
			state: false
		}
	}

	// 身份证号码校验
	var sum = 0,
		weights = [7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2],
		codes = "10X98765432"
	for (var i = 0; i < sId.length - 1; i++) {
		sum += sId[i] * weights[i];
	}
	var last = codes[sum % 11]; //计算出来的最后一位身份证号码
	if (sId[sId.length - 1] != last) {
		return {
			data: '你输入的身份证号长度或格式有误',
			state: false
		}
	}

	return {
		data: '',
		state: true
	}
}
//获取url参数组成json
export function GetQueryJson(e) {
	if(e == 'undefined'){
		return {}
	}else{
		let url=e;//获取url
		let arr=[];//存储参数的数
		let res={};//存储最终JSON结果对象
		arr=url.split('?')[1].split('&');//获取浏览器地址栏中的参数
		for(let i=0;i<arr.length;i++){//遍历参数
			if(arr[i].indexOf('=')!=-1){//如果参数中有值
				let str=arr[i].split('=');
				res[str[0]]=str[1];
			}else{//如果参数中无值
				res[arr[i]]='';
			}
		};
		return res;
	}

}
